/*
 * Copyright (C) 2014, 2016 Karl Wette
 * Copyright (C) 2009-2013 Adam Mercer
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or (at
 * your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with with program; see the file COPYING. If not, write to the
 * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA 02110-1301 USA
 */

/*
 * LALFrameVCSInfo.c - LALFrame VCS Information
 */

#include <stdlib.h>
#include <config.h>

#include <lal/LALVCSInfoType.h>

#if defined(HAVE_LIBLAL)
#include <lal/LALVCSInfoHeader.h>
#endif
#if defined(HAVE_LIBLALFRAME)
#include <lal/LALFrameVCSInfoHeader.h>
#endif
#if defined(HAVE_LIBLALMETAIO)
#include <lal/LALMetaIOVCSInfoHeader.h>
#endif
#if defined(HAVE_LIBLALSIMULATION)
#include <lal/LALSimulationVCSInfoHeader.h>
#endif
#if defined(HAVE_LIBLALBURST)
#include <lal/LALBurstVCSInfoHeader.h>
#endif
#if defined(HAVE_LIBLALINSPIRAL)
#include <lal/LALInspiralVCSInfoHeader.h>
#endif
#if defined(HAVE_LIBLALINFERENCE)
#include <lal/LALInferenceVCSInfoHeader.h>
#endif
#if defined(HAVE_LIBLALPULSAR)
#include <lal/LALPulsarVCSInfoHeader.h>
#endif

#include "LALFrameVCSInfoHeader.h"
#include "LALFrameBuildInfoHeader.h"

/* VCS and build information */
const LALVCSInfo lalFrameVCSInfo = {
  .name = "LALFrame",
  .version = LALFRAME_VERSION,
  .vcsId = LALFRAME_VCS_ID,
  .vcsDate = LALFRAME_VCS_DATE,
  .vcsBranch = LALFRAME_VCS_BRANCH,
  .vcsTag = LALFRAME_VCS_TAG,
  .vcsAuthor = LALFRAME_VCS_AUTHOR,
  .vcsCommitter = LALFRAME_VCS_COMMITTER,
  .vcsClean = LALFRAME_VCS_CLEAN,
  .vcsStatus = LALFRAME_VCS_STATUS,
  .configureArgs = LALFRAME_CONFIGURE_ARGS,
  .configureDate = LALFRAME_CONFIGURE_DATE,
  .buildDate = LALFRAME_BUILD_DATE,
};

/* Identable VCS and build information */
const LALVCSInfo lalFrameVCSIdentInfo = {
  .name = "$LALFrameName: " "LALFrame" " $",
  .version = "$LALFrameVersion: " LALFRAME_VERSION " $",
  .vcsId = "$LALFrameVCSId: " LALFRAME_VCS_ID " $",
  .vcsDate = "$LALFrameVCSDate: " LALFRAME_VCS_DATE " $",
  .vcsBranch = "$LALFrameVCSBranch: " LALFRAME_VCS_BRANCH " $",
  .vcsTag = "$LALFrameVCSTag: " LALFRAME_VCS_TAG " $",
  .vcsAuthor = "$LALFrameVCSAuthor: " LALFRAME_VCS_AUTHOR " $",
  .vcsCommitter = "$LALFrameVCSCommitter: " LALFRAME_VCS_COMMITTER " $",
  .vcsClean = "$LALFrameVCSClean: " LALFRAME_VCS_CLEAN " $",
  .vcsStatus = "$LALFrameVCSStatus: " LALFRAME_VCS_STATUS " $",
  .configureArgs = "$LALFrameConfigureArgs: " LALFRAME_CONFIGURE_ARGS " $",
  .configureDate = "$LALFrameConfigureDate: " LALFRAME_CONFIGURE_DATE " $",
  .buildDate = "$LALFrameBuildDate: " LALFRAME_BUILD_DATE " $",
};

/* NULL-terminated list of library and dependencies VCS and build information */
const LALVCSInfoList lalFrameVCSInfoList = {
#if defined(HAVE_LIBLAL)
  &lalVCSInfo,
#endif
#if defined(HAVE_LIBLALFRAME)
  &lalFrameVCSInfo,
#endif
#if defined(HAVE_LIBLALMETAIO)
  &lalMetaIOVCSInfo,
#endif
#if defined(HAVE_LIBLALSIMULATION)
  &lalSimulationVCSInfo,
#endif
#if defined(HAVE_LIBLALBURST)
  &lalBurstVCSInfo,
#endif
#if defined(HAVE_LIBLALINSPIRAL)
  &lalInspiralVCSInfo,
#endif
#if defined(HAVE_LIBLALINFERENCE)
  &lalInferenceVCSInfo,
#endif
#if defined(HAVE_LIBLALPULSAR)
  &lalPulsarVCSInfo,
#endif
  &lalFrameVCSInfo,
  NULL
};

#if LALFRAME_VERSION_DEVEL != 0
/*
 * VCS header/library mismatch link check function:
 * This function will successfully link only if the link check functions defined
 * in the included LAL VCS info headers (e.g. LAL_VCS_LINK_CHECK() defined in
 * <lal/LALVCSInfoHeader.h>) are present in the LAL libraries being linked
 * against. A successful link ensures that the LAL headers included by this
 * library are consistent with the LAL libraries linked against by this library.
 */
void LALFRAME_VCS_LINK_CHECK(void)
{
#if defined(HAVE_LIBLAL) && LAL_VERSION_DEVEL != 0
  LAL_VCS_LINK_CHECK();
#endif
#if defined(HAVE_LIBLALFRAME) && LALFRAME_VERSION_DEVEL != 0
  LALFRAME_VCS_LINK_CHECK();
#endif
#if defined(HAVE_LIBLALMETAIO) && LALMETAIO_VERSION_DEVEL != 0
  LALMETAIO_VCS_LINK_CHECK();
#endif
#if defined(HAVE_LIBLALSIMULATION) && LALSIMULATION_VERSION_DEVEL != 0
  LALSIMULATION_VCS_LINK_CHECK();
#endif
#if defined(HAVE_LIBLALBURST) && LALBURST_VERSION_DEVEL != 0
  LALBURST_VCS_LINK_CHECK();
#endif
#if defined(HAVE_LIBLALINSPIRAL) && LALINSPIRAL_VERSION_DEVEL != 0
  LALINSPIRAL_VCS_LINK_CHECK();
#endif
#if defined(HAVE_LIBLALINFERENCE) && LALINFERENCE_VERSION_DEVEL != 0
  LALINFERENCE_VCS_LINK_CHECK();
#endif
#if defined(HAVE_LIBLALPULSAR) && LALPULSAR_VERSION_DEVEL != 0
  LALPULSAR_VCS_LINK_CHECK();
#endif
}
#endif
